@@ -24,10 +24,7 @@
  * jl  09.07.98 added option -S to start a script at startup
  * mark.einon@gmail.com 16/02/11 - Added option to timestamp terminal output
  */
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
 #include <getopt.h>
 #include <wchar.h>
 #include <wctype.h>
@@ -75,6 +72,9 @@ static const char *c7[] = { N_("   Yes  "), N_("   No   "), NULL };
 /* Initialize modem port. */
 void port_init(void)
 {
+  if (portfd_is_socket)
+    return;
+
   m_setparms(portfd, P_BAUDRATE, P_PARITY, P_BITS, P_STOPB,
              P_HASRTS[0] == 'Y', P_HASXON[0] == 'Y', P_RS485_EN[0] == 'Y');
   m_set485parms(portfd, P_RS485_EN[0] == 'Y',
@@ -1232,7 +1232,6 @@ int main(int argc, char **argv)
   capbuf = _IONBF;
   online = -1;
   linespd = 0;
-  stdattr = XA_NORMAL;
   us = NULL;
   addlf = 0;
   addcr = 0;
@@ -1241,16 +1240,16 @@ int main(int argc, char **argv)
   display_hex = 0;
   local_echo = 0;
   strcpy(capname, "minicom.cap");
-  lockfile[0] = 0;
+  lockfile_mode = Lockfile_mode_unset;
   tempst = 0;
   st = NULL;
   us = NULL;
   bogus_dcd = 0;
-  usecolor = 0;
+  usecolor = 1;
   screen_ibmpc = screen_iso = 1;
   useattr = 1;
   strncpy(termtype, getenv("TERM") ? getenv("TERM") : "dumb", sizeof(termtype));
-  stdattr = XA_NORMAL;
+  stdattr = XA_BOLD;
   use_port = "dfl";
   alt_override = 0;
   scr_name[0] = 0;
@@ -1676,7 +1675,9 @@ int main(int argc, char **argv)
             port_date[sizeof(port_date) - 1] = 0;
           }
       }
-    mc_wprintf(us, "%s %s%s\r\n", _("Port"), P_PORT, port_date);
+    const char lfm_s[Lockfile_mode_max] = { '?', 'U', 'F', 'T' };
+    mc_wprintf(us, "%s %s%s [%c]\r\n", _("Port"), P_PORT, port_date,
+	       lfm_s[lockfile_mode]);
   }
 
   if (using_iconv())
@@ -1885,8 +1886,7 @@ dirty_goto:
   mc_wclose(st, 0);
   mc_wclose(stdwin, 1);
   keyboard(KUNINSTALL, 0);
-  lockfile_remove();
-  close(portfd);
+  device_close();
 
   if (quit != NORESET && P_CALLIN[0])
     fastsystem(P_CALLIN, NULL, NULL, NULL);
