@@ -23,10 +23,7 @@
  *    jl 06.07.98 use conversion tables with the capture file
  *    mark.einon@gmail.com 16/02/11 - Added option to timestamp terminal output
  */
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
 #include <time.h>
 #include <stdint.h>
 #include "port.h"
@@ -44,6 +41,7 @@
  * 5 - ESC )
  * 6 - ESC #
  * 7 - ESC P
+ * 8 - ESC ]
  */
 static int esc_s = 0;
 
@@ -96,7 +94,6 @@ unsigned char vt_outmap[256] = {
 #include "defmap.h"
 };
 
-#if TRANSLATE
 /* Taken from the Linux kernel source: linux/drivers/char/console.c */
 static char * vt_map[] = {
 /* 8-bit Latin-1 mapped to the PC character set: '.' means non-printable */
@@ -131,7 +128,6 @@ static char * vt_map[] = {
 };
 static char *vt_trans[2];
 static int vt_charset;          /* Character set. */
-#endif
 
 static int vt_echo;		/* Local echo on/off. */
 int vt_nl_delay;		/* Delay after CR key */
@@ -165,10 +161,8 @@ static short newy2 = 23;
 /* Saved color and positions */
 static short savex, savey, saveattr = XA_NORMAL, savecol = 112;
 
-#if TRANSLATE
 static short savecharset;
 static char *savetrans[2];
-#endif
 
 /*
  * Initialize the emulator once.
@@ -226,11 +220,9 @@ void vt_init(int type, int fg, int bg, int wrap, int add_lf, int add_cr)
   vt_tabs[2] =
   vt_tabs[3] =
   vt_tabs[4] = 0x01010101;
-#if TRANSLATE
   vt_charset = 0;
   vt_trans[0] = savetrans[0] = vt_map[0];
   vt_trans[1] = savetrans[1] = vt_map[1];
-#endif
   ptr = 0;
   memset(escparms, 0, sizeof(escparms));
   esc_s = 0;
@@ -310,6 +302,9 @@ static void state1(int c)
     case 'P': /* ESC P (DCS, Device Control String) */
       esc_s = 7;
       return;
+    case ']': /* ESC ] (OSC, Operating System Command) */
+      esc_s = 8;
+      return;
     case 'D': /* Cursor down */
     case 'M': /* Cursor up */
       x = vt_win->curx;
@@ -337,19 +332,15 @@ static void state1(int c)
       savey = vt_win->cury;
       saveattr = vt_win->attr;
       savecol = vt_win->color;
-#if TRANSLATE
       savecharset = vt_charset;
       savetrans[0] = vt_trans[0];
       savetrans[1] = vt_trans[1];
-#endif
       break;
     case '8': /* Restore them */
     case 'u':
-#if TRANSLATE
       vt_charset = savecharset;
       vt_trans[0] = savetrans[0];
       vt_trans[1] = savetrans[1];
-#endif
       vt_win->color = savecol; /* HACK should use mc_wsetfgcol etc */
       mc_wsetattr(vt_win, saveattr);
       mc_wlocate(vt_win, savex, savey);
@@ -540,18 +531,14 @@ static void state2(int c)
       savey = vt_win->cury;
       saveattr = vt_win->attr;
       savecol = vt_win->color;
-#if TRANSLATE
       savecharset = vt_charset;
       savetrans[0] = vt_trans[0];
       savetrans[1] = vt_trans[1];
-#endif
       break;
     case 'u': /* Restore them */
-#if TRANSLATE
       vt_charset = savecharset;
       vt_trans[0] = savetrans[0];
       vt_trans[1] = savetrans[1];
-#endif
       vt_win->color = savecol; /* HACK should use mc_wsetfgcol etc */
       mc_wsetattr(vt_win, saveattr);
       mc_wlocate(vt_win, savex, savey);
@@ -800,10 +787,6 @@ static void state3(int c)
 static void state4(int c)
 {
   /* Switch Character Sets. */
-#if !TRANSLATE
-  /* IGNORED */
-  (void)c;
-#else
   switch (c) {
     case 'A':
     case 'B':
@@ -814,7 +797,6 @@ static void state4(int c)
       vt_trans[0] = vt_map[1];
       break;
   }
-#endif
   esc_s = 0;
 }
 
@@ -824,10 +806,6 @@ static void state4(int c)
 static void state5(int c)
 {
   /* Switch Character Sets. */
-#if !TRANSLATE
-  /* IGNORED */
-  (void)c;
-#else
   switch (c) {
     case 'A':
     case 'B':
@@ -838,7 +816,6 @@ static void state5(int c)
       vt_trans[1] = vt_map[1];
       break;
   }
-#endif
   esc_s = 0;
 }
 
@@ -917,6 +894,39 @@ static void state7(int c)
   buf[pos++] = c;
 }
 
+/*
+ * ESC ] Seen.
+ */
+static void state8(int c)
+{
+  /*
+   * Operating system commands.
+   * No support is currently implemented, they are simply thrown away.
+   * The sequences end with '\a' (BEL, terminal bell) or ESC-\ (ST).
+   */
+  static int state = 0;
+  switch (c) {
+    case 7:
+      /* Got BEL - done */
+      state = 0;
+      esc_s = 0;
+      return;
+    case ESC:
+      /* Possibly start of ST */
+      state = 1;
+      return;
+    case '\\':
+      /* Possibly end of ST */
+      if (state == 1) {
+	state = 0;
+	esc_s = 0;
+	return;
+      }
+      break;
+  };
+  state = 0;
+}
+
 static void output_s(const char *s)
 {
   mc_wputs(vt_win, s);
@@ -1031,18 +1041,12 @@ void vt_out(int ch, wchar_t wc)
       mc_winclr(vt_win);
       mc_wlocate(vt_win, 0, 0);
       break;
-#if !TRANSLATE
-    case 14:
-    case 15:  /* Change character set. Not supported. */
-      break;
-#else
     case 14:
       vt_charset = 1;
       break;
     case 15:
       vt_charset = 0;
       break;
-#endif
     case 24:
     case 26:  /* Cancel escape sequence. */
       esc_s = 0;
@@ -1057,10 +1061,15 @@ void vt_out(int ch, wchar_t wc)
       if(vt_addcr)
         mc_wputc(vt_win, '\r');
       output_c(c);
-	  break;
+      break;
     case '\b':
+      output_c(c); /* Backspace */
+      break;
     case 7: /* Bell */
-      output_c(c);
+      if (esc_s == 8)
+        go_on = 1;
+      else
+        output_c(c);
       break;
     default:
       go_on = 1;
@@ -1076,10 +1085,8 @@ void vt_out(int ch, wchar_t wc)
         fputc(P_CONVCAP[0] == 'Y' ? vt_inmap[c] : c, capfp);
       if (!using_iconv()) {
         c = vt_inmap[c];    /* conversion 04.09.97 / jl */
-#if TRANSLATE
         if (vt_type == VT100 && vt_trans[vt_charset] && vt_asis == 0)
           c = vt_trans[vt_charset][c];
-#endif
       }
       if (wc == 0)
         one_mbtowc (&wc, (char *)&c, 1); /* returns 1 */
@@ -1109,6 +1116,9 @@ void vt_out(int ch, wchar_t wc)
     case 7:
       state7(c);
       break;
+    case 8:
+      state8(c);
+      break;
   }
 }
 
